DropDownDate class
Constructors
-
DropDownDate({Key? key, DateTime? currentDate, required DateTime? initialDate, required DateTime firstDate, required DateTime lastDate, required ValueChanged<
DateTime> onDateChanged, ValueChanged<DateTime> ? onDisplayedMonthChanged, DatePickerMode initialCalendarMode = DatePickerMode.day, SelectableDayPredicate? selectableDayPredicate, Widget? customTopWidget, String? hintText, String? labelText, Widget? inputDescriptionWidget, bool showDoneOnHeader = false, Widget? bottomSheetTitle, bool isDismissible = true, Widget? submitButtonChild, int? submitButtonFlex, Widget? cancelButtonChild, EdgeInsets? buttonPadding, String? searchHintText = 'Search', bool fromSide = false, double? widthSide, EdgeInsetsGeometry? margin, Color? color, TextStyle? textStyle, TextStyle? textStyleSelected, Color? selectedColor, Color dropDownBackgroundColor = Colors.transparent, BottomSheetCalListener? bottomSheetListener, bool noCloseDialog = false})
Properties
- bottomSheetListener → BottomSheetCalListener?
-
bottomSheetListener that listens for BottomSheet bubbling up the tree.
final
- bottomSheetTitle → Widget?
-
This gives the bottom sheet title.
final
-
final
- cancelButtonChild → Widget?
-
final
- color → Color?
-
final
- currentDate → DateTime?
-
The DateTime representing today. It will be highlighted in the day grid.
final
- customTopWidget → Widget?
-
final
- dropDownBackgroundColor → Color
-
This will set the background color to the dropdown.
final
- firstDate → DateTime
-
The earliest allowable DateTime that the user can select.
final
- fromSide → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hintText → String?
-
final
- initialCalendarMode → DatePickerMode
-
The initial display of the calendar picker.
final
- initialDate → DateTime?
-
The initially selected DateTime that the picker should display.
final
- inputDescriptionWidget ↔ Widget?
-
getter/setter pair
- isDismissible → bool
-
isDismissible Specifies whether the bottom sheet will be dismissed when user taps on the scrim.
If true, the bottom sheet will be dismissed when user taps on the scrim.
by default it is
True.final - labelText → String?
-
final
- lastDate → DateTime
-
The latest allowable DateTime that the user can select.
final
- margin ↔ EdgeInsetsGeometry?
-
getter/setter pair
- noCloseDialog → bool
-
final
-
onDateChanged
→ ValueChanged<
DateTime> -
Called when the user selects a date in the picker.
final
-
onDisplayedMonthChanged
→ ValueChanged<
DateTime> ? -
Called when the user navigates to a new month/year in the picker.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchHintText → String?
-
searchHintText is use to show the hint text into the search widget.
by default it is
Searchtext.final - selectableDayPredicate → SelectableDayPredicate?
-
Function to provide full control over which dates in the calendar can be selected.
final
- selectedColor → Color?
-
final
- showDoneOnHeader → bool
-
final
- submitButtonChild → Widget?
-
You can set your custom submit button when the multiple selection is enabled.
final
- submitButtonFlex → int?
-
final
- textStyle → TextStyle?
-
final
- textStyleSelected → TextStyle?
-
final
- widthSide → double?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited